@@ -15,7 +15,7 @@ from . import GlobalOptions
     "--saml-client",
     "saml_client_name",
     default="auto",
-    type=click.Choice(["auto", "aws-okta", "saml2aws"]),
+    type=click.Choice(["auto", "aws-okta", "saml2aws", "aws-profile"]),
     help="the SAML client type to use",
 )
 @click.option(
