@@ -1,3 +1,5 @@
+import shlex
+from subprocess import CalledProcessError
 from typing import Mapping, Pattern, Type
 
 from click import ClickException
@@ -24,8 +26,12 @@ class CliErrorMeta(type):
 class CliError(ClickException, metaclass=CliErrorMeta):
     def __init__(self, *args, report=False, **kwargs) -> None:
         super().__init__(*args, **kwargs)
-        if report:
-            capture_exception(self)
+        self.report = report
+
+    def show(self):
+        if self.report:
+            capture_exception()
+        super().show()
 
 
 class CliErrorWithHint(CliError):
@@ -35,6 +41,11 @@ class CliErrorWithHint(CliError):
 
 
 class SuppressedError(CliError):
+    def __init__(self, wrapped: CalledProcessError, echo=False):
+        if echo:
+            print(wrapped.stderr)
+        super().__init__(shlex.join(wrapped.cmd))
+
     def show(self):
         pass
 
@@ -84,8 +95,8 @@ class BotoError(CliErrorWithHint):
 
 
 class FailedSubprocessError(CliError):
-    def __init__(self, command) -> None:
-        super().__init__(f"Cannot run {command}")
+    def __init__(self, wrapped: CalledProcessError):
+        super().__init__(f"Cannot run {shlex.join(wrapped.cmd)}")
 
 
 class WrappedSubprocessError(CliError):
