@@ -1,12 +1,17 @@
 import os
+from contextlib import contextmanager
 from datetime import datetime
 from pathlib import Path
+from tempfile import NamedTemporaryFile
 from typing import Any, Final, Iterator, Literal, MutableMapping, TypedDict, cast
 
 import immutables
 import yaml
+from portalocker import Lock
+from portalocker.constants import LOCK_EX, LOCK_NB, LOCK_SH
+from portalocker.exceptions import AlreadyLocked
 
-from .os import safe_create
+from .io import TruncatingStringIO
 
 ConfigKey = Literal["org", "email"]
 
@@ -21,15 +26,36 @@ def sym_config_file(file_name: str) -> Path:
 
 
 class SymConfigFile:
-    def __init__(self, file_name: str):
-        self.path = sym_config_file(file_name)
+    def __init__(self, *, file_name: str, **dependencies):
+        path = Path()
+        for k, v in sorted(dependencies.items()):
+            path = path / k / str(v)
+        self.path = sym_config_file(path / file_name)
+
+        self.read_lock = Lock(str(self.path), mode="r", flags=LOCK_SH | LOCK_NB)
+        self.write_lock = Lock(
+            str(self.path), mode="w+", flags=LOCK_EX | LOCK_NB, fail_when_locked=True
+        )
 
     def __enter__(self):
-        self.file = safe_create(self.path)
-        return self.file.__enter__()
+        self.path.parent.mkdir(parents=True, exist_ok=True)
+        try:
+            # acquire read lock, hold across context
+            self.value = self.read_lock.acquire().read()
+        except FileNotFoundError:
+            self.value = None
+        self.file = TruncatingStringIO(initial_value=self.value)
+        return self.file
 
     def __exit__(self, type, value, traceback):
-        self.file.__exit__(type, value, traceback)
+        self.read_lock.release()  # release read lock
+        if value:
+            return
+        if self.file.tell() == 0:
+            return
+        if self.value != (value := self.file.getvalue()):
+            with self.exclusive_access() as f:
+                f.write(value)
 
     def __str__(self):
         return str(self.path)
@@ -38,6 +64,22 @@ class SymConfigFile:
         with self as f:
             f.write(s)
 
+    @contextmanager
+    def exclusive_access(self):
+        try:
+            with self.write_lock as f:  # acquire write lock
+                yield f
+        except AlreadyLocked:  # another thread is writing same value
+            with NamedTemporaryFile(mode="w") as f:  # throw away the input
+                yield f
+
+    @contextmanager
+    def exclusive_create(self):
+        with self.exclusive_access() as f:
+            if f.buffer.peek():
+                raise AlreadyLocked()
+            yield f
+
 
 class ServerConfigSchema(TypedDict):
     last_connection: datetime
@@ -51,23 +93,19 @@ class ConfigSchema(TypedDict, total=False):
 
 
 class Config(MutableMapping[ConfigKey, Any]):
-    __slots__ = ["path", "config"]
+    __slots__ = ["file", "config"]
 
-    path: Final[Path]
+    file: Final[SymConfigFile]
     config: Final[ConfigSchema]
 
     def __init__(self) -> None:
-        self.path = sym_config_file("config.yml")
-        self.path.parent.mkdir(parents=True, exist_ok=True)
-        try:
-            with self.path.open() as f:
-                config = cast(ConfigSchema, yaml.safe_load(stream=f) or {})
-        except FileNotFoundError:
-            config = ConfigSchema()
+        self.file = SymConfigFile(file_name="config.yml")
+        with self.file as f:
+            config = cast(ConfigSchema, yaml.safe_load(stream=f) or {})
         self.config = config
 
     def __flush(self) -> None:
-        with safe_create(self.path) as f:
+        with self.file as f:
             yaml.safe_dump(self.config, stream=f)
 
     def __getitem__(self, key: ConfigKey) -> Any:
