@@ -1,4 +1,5 @@
 from configparser import ConfigParser
+from pathlib import Path
 from typing import Final, Iterator, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
@@ -21,5 +22,8 @@ class AwsProfile(SAMLClient):
         with push_env("AWS_PROFILE", self.resource):
             yield *args, opts
 
+    def is_setup(self) -> bool:
+        return (Path.home() / '.aws' / 'credentials').exists()
+
     def _ensure_config(self, profile: Profile) -> ConfigParser:
         return ConfigParser()
