@@ -3,9 +3,10 @@ from typing import Literal, Type
 from ..helpers.os import has_command
 from . import SAMLClient
 from .aws_okta import AwsOkta
+from .aws_profile import AwsProfile
 from .saml2aws import Saml2Aws
 
-SAMLClientName = Literal["auto", "aws-okta", "saml2aws"]
+SAMLClientName = Literal["auto", "aws-okta", "saml2aws", "aws-profile"]
 
 
 def choose_saml_client(saml_client_name: SAMLClientName) -> Type[SAMLClient]:
@@ -13,5 +14,10 @@ def choose_saml_client(saml_client_name: SAMLClientName) -> Type[SAMLClient]:
         return AwsOkta
     elif saml_client_name == "saml2aws":
         return Saml2Aws
+    elif saml_client_name == "aws-profile":
+        return AwsProfile
     else:
-        return Saml2Aws if has_command("saml2aws") else AwsOkta
+        for client in [Saml2Aws, AwsOkta, AwsProfile]:
+            if has_command(client.binary):
+                return client
+    return AwsProfile
