@@ -35,7 +35,10 @@ def test_context(
 
 def _subprocess_friendly_asserter(args: Tuple[Type[P], Sandbox]) -> None:
     constructor, sandbox, expected_command = args
-    capture_command = CaptureCommand(MonkeyPatch())
+    monkeypatch = MonkeyPatch()
+    capture_command = CaptureCommand(monkeypatch)
+
+    monkeypatch.setattr(SAMLClient, "check_is_setup", lambda self: ...)
 
     with sandbox.push_xdg_config_home(), sandbox.push_exec_path(), capture_command():
         Config.instance()["org"] = "sym"
