@@ -1,13 +1,17 @@
+from multiprocessing import Pool
+
 import pytest
 
 from sym.cli.saml_clients.aws_okta import AwsOkta
 from sym.cli.tests.helpers.capture import CaptureCommand
 from sym.cli.tests.saml_clients.conftest import TestContextFixture
 
-pytestmark = pytest.mark.usefixtures("click_context")
+pytestmark = [
+    pytest.mark.usefixtures("click_context"),
+    pytest.mark.parametrize(argnames=["constructor"], argvalues=[[AwsOkta]]),
+]
 
 
-@pytest.mark.parametrize(argnames=["constructor"], argvalues=[[AwsOkta]])
 def test_aws_okta(
     test_context: TestContextFixture[AwsOkta], capture_command: CaptureCommand
 ) -> None:
@@ -19,7 +23,6 @@ def test_aws_okta(
     )
 
 
-@pytest.mark.parametrize(argnames=["constructor"], argvalues=[[AwsOkta]])
 def test_aws_okta_debug(
     test_context: TestContextFixture[AwsOkta], capture_command: CaptureCommand
 ) -> None:
@@ -27,3 +30,10 @@ def test_aws_okta_debug(
         with capture_command():
             aws_okta.exec("env")
     capture_command.assert_command("aws-okta --debug exec sym -- env")
+
+
+def test_aws_okta_multi_threads(subprocess_friendly_asserter) -> None:
+    commands = ("aws-okta exec sym -- env",)
+    f, *args = subprocess_friendly_asserter
+    with Pool(processes=4) as pool:
+        pool.map(f, [(*args, commands)] * 100)
