@@ -20,10 +20,10 @@ def test_resources(click_setup):
     with click_setup() as runner:
         result = runner.invoke(click_command, ["resources"])
         assert result.exit_code == 0
-        assert result.output == "chris (Chris)\njon (Jon)\n"
+        assert result.output == "test (Test)\n"
 
 
 def test_ssh(click_setup):
     with click_setup() as runner:
-        result = runner.invoke(click_command, ["exec", "jon", "--", "aws"])
+        result = runner.invoke(click_command, ["exec", "test", "--", "aws"])
         assert result.exit_code == 0
